//
//  ContentView.swift
//  TagsDemo
//
//  Created by Muhammad Ibrahim on 16/10/2021.
//

import SwiftUI
import WSTagsField

struct ContentView: View {
    @State var tagText = ""
    
    var body: some View {
        TagsView(tag: $tagText)
//            .frame(height: 100, alignment: .center)
//            .background(Color.red)
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}

struct TagsView: UIViewRepresentable {
    @Binding var tag: String

    func makeCoordinator() -> Coordinator {
        Coordinator(tag: $tag)
    }
    
    func makeUIView(context: Context) -> WSTagsField {
        let tagsField = WSTagsField()
        tagsField.layoutMargins = UIEdgeInsets(top: 2, left: 6, bottom: 2, right: 6)
        tagsField.contentInset = UIEdgeInsets(top: 10, left: 10, bottom: 10, right: 10)
        tagsField.spaceBetweenLines = 5.0
        tagsField.spaceBetweenTags = 10.0
        tagsField.placeholder = "Enter contact"
//        tagsField.font = .systemFont(ofSize: 12.0)
//        tagsField.backgroundColor = .white
//        tagsField.tintColor = .green
//        tagsField.textColor = .black
//        tagsField.textColor = .blue
//        tagsField.selectedColor = .black
//        tagsField.selectedTextColor = .red
//        tagsField.delimiter = ","
//        tagsField.isDelimiterVisible = true
//        tagsField.placeholderColor = .green
        tagsField.placeholderAlwaysVisible = true
//        tagsField.keyboardAppearance = .dark
//        tagsField.returnKeyType = .next
//        tagsField.acceptTagOption = .space
//        tagsField.shouldTokenizeAfterResigningFirstResponder = true
        
        tagsField.onDidAddTag = { field, tag in
            print("DidAddTag", tag.text)
        }

        tagsField.onDidRemoveTag = { field, tag in
            print("DidRemoveTag", tag.text)
        }

        tagsField.onDidChangeText = { _, text in
            print("DidChangeText")
        }

        tagsField.onDidChangeHeightTo = { _, height in
            print("HeightTo", height)
        }

        tagsField.onValidateTag = { tag, tags in
            // custom validations, called before tag is added to tags list
            return tag.text != "#" && !tags.contains(where: { $0.text.uppercased() == tag.text.uppercased() })
        }

        print("List of Tags Strings:", tagsField.tags.map({$0.text}))
        
        return tagsField
    }

    func updateUIView(_ tagsField: WSTagsField, context: Context) {
        tagsField.text = tag
    }
}

extension TagsView {
    class Coordinator: NSObject {
        @Binding private var tag: String

        init(tag: Binding<String>) {
            // Here we assign our injected Binding directly
            // to our text property, rather than assigning
            // its wrapped value:
            _tag = tag
        }
    }
}
